Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2391)

Unified Diff: chrome/browser/signin/signin_manager_factory.h

Issue 44083005: policy: Remove UserCloudPolicyManagerFactory's dependency on Profile. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/signin/signin_manager_factory.h
diff --git a/chrome/browser/signin/signin_manager_factory.h b/chrome/browser/signin/signin_manager_factory.h
index 827840434cf2cd10e13f22d26caec28e524407ae..075d533dd3f3a6d40fb462e79dc6d38df5fd534a 100644
--- a/chrome/browser/signin/signin_manager_factory.h
+++ b/chrome/browser/signin/signin_manager_factory.h
@@ -25,15 +25,17 @@ class SigninManagerFactory : public BrowserContextKeyedServiceFactory {
// SigninManager (for example, if |profile| is incognito).
static SigninManagerBase* GetForProfile(Profile* profile);
- // Returns the instance of SigninManager associated with this profile. Returns
- // null if no SigninManager instance currently exists (will not create a new
- // instance).
- static SigninManagerBase* GetForProfileIfExists(Profile* profile);
+ // Returns the instance of SigninManager associated with this browser context.
+ // Returns null if no SigninManager instance currently exists (will not create
+ // a new instance).
+ static SigninManagerBase* GetForBrowserContextIfExists(
+ content::BrowserContext* context);
#else
// On non-ChromeOS platforms, the SigninManager the factory creates will be
// an instance of the extended SigninManager class.
static SigninManager* GetForProfile(Profile* profile);
- static SigninManager* GetForProfileIfExists(Profile* profile);
+ static SigninManager* GetForBrowserContextIfExists(
+ content::BrowserContext* context);
#endif
// Returns an instance of the SigninManagerFactory singleton.

Powered by Google App Engine
This is Rietveld 408576698